.. _examples-index:

Examples
========

.. toctree::
   :maxdepth: 2

   acoustics-index
   dg-index
   diffusion-index
   homogenization-index
   large_deformation-index
   linear_elasticity-index
   miscellaneous-index
   multi_physics-index
   navier_stokes-index
   phononic-index
   quantum-index
